@@ -35,7 +35,6 @@ class Generic(metaclass=abc.ABCMeta):
     DYNAMIC_PARAMS: DynamicParamDict = {}
     CANCEL_MAPPING: CancelDict = {}
     _ABSTRACT = True
-    INIT_PRIORITY = 0  # OT with the highest priority will be initialized first
 
     def __init__(self, obj_id: str, name: str, settings: Optional[Settings] = None) -> None:
 
@@ -56,9 +55,13 @@ class Generic(metaclass=abc.ABCMeta):
 
     @classmethod
     def description(cls) -> str:
-        if not cls.__doc__:
+        """Returns short description from docstring comment."""
+
+        docs = parse_docstring(cls.__doc__)
+
+        if not docs.short_description:
             return "No description available."
-        return parse_docstring(cls.__doc__)["short_description"]
+        return docs.short_description
 
     def scene_object(self) -> SceneObject:
         return SceneObject(self.name, self.__class__.__name__, id=self.id)
@@ -75,6 +78,9 @@ class Generic(metaclass=abc.ABCMeta):
 
 
 class GenericWithPose(Generic):
+
+    mesh_filename: Optional[str] = None
+
     def __init__(
         self,
         obj_id: str,
@@ -133,16 +139,9 @@ class GenericWithPose(Generic):
                 assert self.id not in scene_service.collision_ids()
                 scene_service.upsert_collision(self.collision_model, self.pose)
             if self._enabled and not enabled:
-                # TODO not sure if it's intentional, but stopped scene service 0.4.2 returns empty list of collision IDs
-                # assert self.id in scene_service.collision_ids()
                 scene_service.delete_collision_id(self.id)
         self._enabled = enabled
 
-    def cleanup(self) -> None:
-
-        super(GenericWithPose, self).cleanup()
-        self.enabled = False
-
 
 class RobotException(Arcor2Exception):
     pass
@@ -178,8 +177,6 @@ class Robot(GenericWithPose, metaclass=abc.ABCMeta):
         except Arcor2NotImplemented:
             pass
 
-        return None
-
     def move_to_calibration_pose(self) -> None:
         raise Arcor2NotImplemented("No calibration pose specified.")
 
@@ -265,6 +262,130 @@ class Robot(GenericWithPose, metaclass=abc.ABCMeta):
         raise Arcor2NotImplemented()
 
     def set_hand_teaching_mode(self, enabled: bool) -> None:
+        raise Arcor2NotImplemented("The robot does not support hand teaching.")
+
+
+class MultiArmRobot(Robot, metaclass=abc.ABCMeta):
+    """Abstract class representing robot and its basic capabilities (motion)"""
+
+    @abc.abstractmethod
+    def get_arm_ids(self) -> Set[str]:
+        """Most robots have just one arm so this method is not abstract and
+        returns one arm id.
+
+        :return:
+        """
+        pass
+
+    @abc.abstractmethod
+    def get_end_effectors_ids(self, arm_id: Optional[str] = None) -> Set[str]:
+        pass
+
+    @abc.abstractmethod
+    def get_end_effector_pose(self, end_effector: str, arm_id: Optional[str] = None) -> Pose:
+        pass
+
+    @abc.abstractmethod
+    def robot_joints(self, arm_id: Optional[str] = None) -> List[Joint]:
+        """With no arm specified, returns all robot joints. Otherwise, returns
+        joints for the given arm.
+
+        :param arm_id:
+        :return:
+        """
+        pass
+
+    @abc.abstractmethod
+    def grippers(self, arm_id: Optional[str] = None) -> Set[str]:
+        return set()
+
+    @abc.abstractmethod
+    def suctions(self, arm_id: Optional[str] = None) -> Set[str]:
+        return set()
+
+    def check_if_ready_to_move(self) -> None:
+        """The method should raise exception when the robot is not ready to
+        move for some reason.
+
+        :return:
+        """
+
+        if self.move_in_progress:  # this holds for all arms
+            raise RobotException("Already moving.")
+
+        # hand-teaching mode is arm specific
+        for arm_id in self.get_arm_ids():
+
+            try:
+                if self.get_hand_teaching_mode(arm_id):
+                    raise RobotException("Can't move in hand teaching mode.")
+            except Arcor2NotImplemented:
+                pass
+
+    def move_to_pose(
+        self, end_effector_id: str, target_pose: Pose, speed: float, safe: bool = True, arm_id: Optional[str] = None
+    ) -> None:
+        """Move given robot's end effector to the selected pose.
+
+        :param end_effector_id:
+        :param target_pose:
+        :param speed:
+        :param safe:
+        :return:
+        """
+
+        assert 0.0 <= speed <= 1.0
+        raise Arcor2NotImplemented("Robot does not support moving to pose.")
+
+    def move_to_joints(
+        self, target_joints: List[Joint], speed: float, safe: bool = True, arm_id: Optional[str] = None
+    ) -> None:
+        """Sets target joint values.
+
+        :param target_joints:
+        :param speed:
+        :param safe:
+        :return:
+        """
+
+        assert 0.0 <= speed <= 1.0
+        raise Arcor2NotImplemented("Robot does not support moving to joints.")
+
+    def inverse_kinematics(
+        self,
+        end_effector_id: str,
+        pose: Pose,
+        start_joints: Optional[List[Joint]] = None,
+        avoid_collisions: bool = True,
+        arm_id: Optional[str] = None,
+    ) -> List[Joint]:
+        """Computes inverse kinematics.
+
+        :param end_effector_id: IK target pose end-effector
+        :param pose: IK target pose
+        :param start_joints: IK start joints
+        :param avoid_collisions: Return non-collision IK result if true
+        :return: Inverse kinematics
+        """
+        raise Arcor2NotImplemented()
+
+    def forward_kinematics(self, end_effector_id: str, joints: List[Joint], arm_id: Optional[str] = None) -> Pose:
+        """Computes forward kinematics.
+
+        :param end_effector_id: Target end effector name
+        :param joints: Input joint values
+        :return: Pose of the given end effector
+        """
+        raise Arcor2NotImplemented()
+
+    def get_hand_teaching_mode(self, arm_id: Optional[str] = None) -> bool:
+        """
+        This is expected to be implemented if the robot supports set_hand_teaching_mode
+        :return:
+        """
+        raise Arcor2NotImplemented()
+
+    def set_hand_teaching_mode(self, enabled: bool, arm_id: Optional[str] = None) -> None:
         raise Arcor2NotImplemented()
 
 
